@@ -2,6 +2,7 @@ from poetry.console.application import Application
 from poetry.plugins.application_plugin import ApplicationPlugin
 
 from poetry_multiproject_plugin.commands.buildproject import project
+from poetry_multiproject_plugin.commands.checkproject import check
 
 
 class MultiProjectPlugin(ApplicationPlugin):
@@ -19,3 +20,7 @@ class MultiProjectPlugin(ApplicationPlugin):
         application.command_loader.register_factory(
             project.command_name, project.ProjectBuildCommand
         )
+
+        application.command_loader.register_factory(
+            check.command_name, check.ProjectCheckCommand
+        )
